Bluetooth class

A Data holding information of nearby Bluetooth devices.

Inheritance
  • Object
  • Serializable
  • Data
  • Bluetooth
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

Bluetooth({DateTime? startScan, DateTime? endScan})
Bluetooth.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
dataType → DataType
The type of this data as a DataType.
no setterinherited
endScan DateTime?
Timestamp of scan end, if available.
getter/setter pair
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
recordId String?
Stable identifier of the source record, if available.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanResult List<BluetoothDevice>
The list of BluetoothDevice found in a scan.
getter/setter pair
startScan DateTime
Timestamp of scan start.
getter/setter pair

Methods

addBluetoothDevice(BluetoothDevice device) → void
addBluetoothDevicesFromRangingResults(Beacon result, String beaconName) → void
addBluetoothDevicesFromScanResults(List<ScanResult> results) → void
equivalentTo(Data other) bool
Is this data equivalent to other?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited